pub struct BVec3A(/* private fields */);Expand description
A 3-dimensional SIMD vector mask.
This type is 16 byte aligned.
Implementations
Sourceimpl BVec3A
impl BVec3A
Sourcepub const fn from_array(a: [bool; 3]) -> BVec3A
pub const fn from_array(a: [bool; 3]) -> BVec3A
Creates a new vector mask from a bool array.
Sourcepub fn bitmask(self) -> u32
pub fn bitmask(self) -> u32
Returns a bitmask with the lowest 3 bits set from the elements of self.
A true element results in a 1 bit and a false element in a 0 bit. Element x goes
into the first lowest bit, element y into the second, etc.