pub struct DPose2 {
pub rotation: DRot2,
pub translation: DVec2,
}Expand description
A 2D pose (rotation + translation), representing a rigid body transformation (f64 precision).
Fields
rotation: DRot2The rotational part of the pose.
translation: DVec2The translational part of the pose.
Implementations
Sourceimpl DPose2
impl DPose2
Sourcepub fn from_translation(translation: DVec2) -> Self
pub fn from_translation(translation: DVec2) -> Self
Creates a pose from a translation vector.
Sourcepub fn translation(x: f64, y: f64) -> Self
pub fn translation(x: f64, y: f64) -> Self
Creates a pose from translation components.
Sourcepub fn from_rotation(rotation: DRot2) -> Self
pub fn from_rotation(rotation: DRot2) -> Self
Creates a pose from a rotation.
Sourcepub fn rotation(angle: f64) -> Self
pub fn rotation(angle: f64) -> Self
Creates a pose that is a pure rotation with the given angle (in radians).
Sourcepub fn from_parts(translation: DVec2, rotation: DRot2) -> Self
pub fn from_parts(translation: DVec2, rotation: DRot2) -> Self
Creates a pose from translation and rotation parts.
Sourcepub fn prepend_translation(self, translation: DVec2) -> Self
pub fn prepend_translation(self, translation: DVec2) -> Self
Prepends a translation to this pose (applies translation in local frame).
Sourcepub fn append_translation(self, translation: DVec2) -> Self
pub fn append_translation(self, translation: DVec2) -> Self
Appends a translation to this pose (applies translation in world frame).
Sourcepub fn transform_point(&self, p: DVec2) -> DVec2
pub fn transform_point(&self, p: DVec2) -> DVec2
Transforms a 2D point by this pose.
This applies both the rotation and translation.
Sourcepub fn transform_vector(&self, v: DVec2) -> DVec2
pub fn transform_vector(&self, v: DVec2) -> DVec2
Transforms a 2D vector by this pose.
This applies only the rotation (ignores translation).
Sourcepub fn inverse_transform_point(&self, p: DVec2) -> DVec2
pub fn inverse_transform_point(&self, p: DVec2) -> DVec2
Transforms a point by the inverse of this pose.
Sourcepub fn inverse_transform_vector(&self, v: DVec2) -> DVec2
pub fn inverse_transform_vector(&self, v: DVec2) -> DVec2
Transforms a vector by the inverse of this pose.