DSymmetricEigen2

Struct DSymmetricEigen2 

pub struct DSymmetricEigen2 {
    pub eigenvalues: DVec2,
    pub eigenvectors: DMat2,
}
The eigen decomposition of a symmetric 2x2 matrix (f64 precision).

Fields

eigenvalues: DVec2

The eigenvalues of the symmetric 2x2 matrix.

eigenvectors: DMat2

The two eigenvectors of the symmetric 2x2 matrix (as columns).

Implementations

Source

impl DSymmetricEigen2

pub fn new(mat: DMat2) -> Self

Computes the eigen decomposition of the given symmetric 2x2 matrix.

The eigenvalues are returned in descending order eigen1 > eigen2. This can be reversed with the reverse method.

pub fn reverse(&self) -> Self

Reverses the order of the eigenvalues and their corresponding eigenvectors.

pub fn eigenvalues(mat: DMat2) -> DVec2

Computes the eigenvalues of a symmetric 2x2 matrix.

Reference: https://croninprojects.org/Vince/Geodesy/FindingEigenvectors.pdf

pub fn eigenvector(mat: DMat2, eigenvalue: f64) -> DVec2

Computes the unit-length eigenvector corresponding to the given eigenvalue of the symmetric 2x2 mat.

Reference: https://croninprojects.org/Vince/Geodesy/FindingEigenvectors.pdf