pub struct Pose3 {
pub rotation: Rot3,
pub translation: Vec3,
}Expand description
A 3D pose (rotation + translation), representing a rigid body transformation (f32 precision).
Fields
rotation: Rot3The rotational part of the pose.
translation: Vec3The translational part of the pose.
Implementations
Sourceimpl Pose3
impl Pose3
Sourcepub fn from_translation(translation: Vec3) -> Self
pub fn from_translation(translation: Vec3) -> Self
Creates a pose from a translation vector.
Sourcepub fn translation(x: f32, y: f32, z: f32) -> Self
pub fn translation(x: f32, y: f32, z: f32) -> Self
Creates a pose from translation components.
Sourcepub fn from_rotation(rotation: Rot3) -> Self
pub fn from_rotation(rotation: Rot3) -> Self
Creates a pose from a rotation.
Sourcepub fn from_parts(translation: Vec3, rotation: Rot3) -> Self
pub fn from_parts(translation: Vec3, rotation: Rot3) -> Self
Creates a pose from translation and rotation parts.
Sourcepub fn new(translation: Vec3, axisangle: Vec3) -> Self
pub fn new(translation: Vec3, axisangle: Vec3) -> Self
Creates a pose from translation and axis-angle rotation.
Sourcepub fn rotation(axisangle: Vec3) -> Self
pub fn rotation(axisangle: Vec3) -> Self
Creates a pose from axis-angle rotation only (no translation).
Sourcepub fn prepend_translation(self, translation: Vec3) -> Self
pub fn prepend_translation(self, translation: Vec3) -> Self
Prepends a translation to this pose (applies translation in local frame).
Sourcepub fn append_translation(self, translation: Vec3) -> Self
pub fn append_translation(self, translation: Vec3) -> Self
Appends a translation to this pose (applies translation in world frame).
Sourcepub fn transform_point(&self, p: Vec3) -> Vec3
pub fn transform_point(&self, p: Vec3) -> Vec3
Transforms a 3D point by this pose.
This applies both the rotation and translation.
Sourcepub fn transform_vector(&self, v: Vec3) -> Vec3
pub fn transform_vector(&self, v: Vec3) -> Vec3
Transforms a 3D vector by this pose.
This applies only the rotation (ignores translation).
Sourcepub fn inverse_transform_point(&self, p: Vec3) -> Vec3
pub fn inverse_transform_point(&self, p: Vec3) -> Vec3
Transforms a point by the inverse of this pose.
Sourcepub fn inverse_transform_vector(&self, v: Vec3) -> Vec3
pub fn inverse_transform_vector(&self, v: Vec3) -> Vec3
Transforms a vector by the inverse of this pose.
Sourcepub fn lerp(&self, other: &Self, t: f32) -> Self
pub fn lerp(&self, other: &Self, t: f32) -> Self
Linearly interpolates between two poses.
Uses spherical linear interpolation for the rotation part.
Sourcepub fn from_mat4(mat: Mat4) -> Self
pub fn from_mat4(mat: Mat4) -> Self
Creates a pose from a homogeneous 4x4 matrix.
The matrix is assumed to represent a rigid body transformation (rotation + translation only, no scaling or shearing).
Sourcepub fn look_at_rh(eye: Vec3, target: Vec3, up: Vec3) -> Pose3
pub fn look_at_rh(eye: Vec3, target: Vec3, up: Vec3) -> Pose3
Builds a right-handed look-at view matrix.
It maps the view direction target - eye to the negative z axis to and the eye to the origin. This conforms to the common notion of right-handed camera look-at view matrix from the computer graphics community, i.e. the camera is assumed to look toward its local -z axis.
Arguments
eye: The eye position.target: The target position.up: A vector approximately aligned with required the vertical axis. The only requirement of this parameter is to not be collinear to target - eye.
Sourcepub fn face_towards(eye: Vec3, target: Vec3, up: Vec3) -> Pose3
pub fn face_towards(eye: Vec3, target: Vec3, up: Vec3) -> Pose3
Creates a pose that corresponds to the local frame of an observer standing at the point eye and looking toward target.
It maps the z axis to the view direction target - eye and the origin to the eye.
Arguments
eye: The observer position.target: The target position.up: Vertical direction. The only requirement of this parameter is to not be collinear to eye - at. Non-collinearity is not checked.