Pose3A

Struct Pose3A 

pub struct Pose3A {
    pub rotation: Rot3,
    pub translation: Vec3A,
}
A 3D pose (rotation + translation), representing a rigid body transformation (f32 precision).

Fields

rotation: Rot3

The rotational part of the pose.

translation: Vec3A

The translational part of the pose.

Implementations

Source

impl Pose3A

pub const IDENTITY: Self

The identity pose (no rotation, no translation).

pub fn identity() -> Self

Creates the identity pose.

pub fn from_translation(translation: Vec3A) -> Self

Creates a pose from a translation vector.

pub fn translation(x: f32, y: f32, z: f32) -> Self

Creates a pose from translation components.

pub fn from_rotation(rotation: Rot3) -> Self

Creates a pose from a rotation.

pub fn from_parts(translation: Vec3A, rotation: Rot3) -> Self

Creates a pose from translation and rotation parts.

pub fn new(translation: Vec3A, axisangle: Vec3A) -> Self

Creates a pose from translation and axis-angle rotation.

pub fn rotation(axisangle: Vec3A) -> Self

Creates a pose from axis-angle rotation only (no translation).

pub fn prepend_translation(self, translation: Vec3A) -> Self

Prepends a translation to this pose (applies translation in local frame).

pub fn append_translation(self, translation: Vec3A) -> Self

Appends a translation to this pose (applies translation in world frame).

pub fn inverse(&self) -> Self

Returns the inverse of this pose.

pub fn inv_mul(&self, rhs: &Self) -> Self

Computes self.inverse() * rhs.

pub fn transform_point(&self, p: Vec3A) -> Vec3A

Transforms a 3D point by this pose.

This applies both the rotation and translation.

pub fn transform_vector(&self, v: Vec3A) -> Vec3A

Transforms a 3D vector by this pose.

This applies only the rotation (ignores translation).

pub fn inverse_transform_point(&self, p: Vec3A) -> Vec3A

Transforms a point by the inverse of this pose.

pub fn inverse_transform_vector(&self, v: Vec3A) -> Vec3A

Transforms a vector by the inverse of this pose.

pub fn lerp(&self, other: &Self, t: f32) -> Self

Linearly interpolates between two poses.

Uses spherical linear interpolation for the rotation part.

pub fn is_finite(&self) -> bool

Returns true if, and only if, all elements are finite.

pub fn is_nan(&self) -> bool

Returns true if any element is NaN.

pub fn to_mat4(&self) -> Mat4

Converts this pose to a homogeneous 4x4 matrix.

pub fn from_mat4(mat: Mat4) -> Self

Creates a pose from a homogeneous 4x4 matrix.

The matrix is assumed to represent a rigid body transformation (rotation + translation only, no scaling or shearing).

pub fn look_at_rh(eye: Vec3A, target: Vec3A, up: Vec3A) -> Pose3A

Builds a right-handed look-at view matrix.

It maps the view direction target - eye to the negative z axis to and the eye to the origin. This conforms to the common notion of right-handed camera look-at view matrix from the computer graphics community, i.e. the camera is assumed to look toward its local -z axis.

Arguments
  • eye: The eye position.
  • target: The target position.
  • up: A vector approximately aligned with required the vertical axis. The only requirement of this parameter is to not be collinear to target - eye.
pub fn face_towards(eye: Vec3A, target: Vec3A, up: Vec3A) -> Pose3A

Creates a pose that corresponds to the local frame of an observer standing at the point eye and looking toward target.

It maps the z axis to the view direction target - eye and the origin to the eye.

Arguments
  • eye: The observer position.
  • target: The target position.
  • up: Vertical direction. The only requirement of this parameter is to not be collinear to eye - at. Non-collinearity is not checked.