pub struct SymmetricEigen2 {
pub eigenvalues: Vec2,
pub eigenvectors: Mat2,
}Expand description
The eigen decomposition of a symmetric 2x2 matrix (f32 precision).
Fields
eigenvalues: Vec2The eigenvalues of the symmetric 2x2 matrix.
eigenvectors: Mat2The two eigenvectors of the symmetric 2x2 matrix (as columns).
Implementations
Sourceimpl SymmetricEigen2
impl SymmetricEigen2
Sourcepub fn new(mat: Mat2) -> Self
pub fn new(mat: Mat2) -> Self
Computes the eigen decomposition of the given symmetric 2x2 matrix.
The eigenvalues are returned in descending order eigen1 > eigen2.
This can be reversed with the reverse method.
Sourcepub fn reverse(&self) -> Self
pub fn reverse(&self) -> Self
Reverses the order of the eigenvalues and their corresponding eigenvectors.
Sourcepub fn eigenvalues(mat: Mat2) -> Vec2
pub fn eigenvalues(mat: Mat2) -> Vec2
Computes the eigenvalues of a symmetric 2x2 matrix.
Reference: https://croninprojects.org/Vince/Geodesy/FindingEigenvectors.pdf
Sourcepub fn eigenvector(mat: Mat2, eigenvalue: f32) -> Vec2
pub fn eigenvector(mat: Mat2, eigenvalue: f32) -> Vec2
Computes the unit-length eigenvector corresponding to the given eigenvalue
of the symmetric 2x2 mat.
Reference: https://croninprojects.org/Vince/Geodesy/FindingEigenvectors.pdf